@@ -4,7 +4,7 @@
 #include "spvm_typedecl.h"
 
 struct spvm_field_access {
-  SPVM_OP* op_term;
+  SPVM_OP* op_invocant;
   SPVM_OP* op_name;
   SPVM_FIELD* field;
   int32_t inline_expansion;
