@@ -21,6 +21,14 @@ This object is immutable and its value cannot be changed.
 
 L<Byte|SPVM::Byte> is automatically loaded just after the program starts.
 
+=head1 Fields
+
+=head2 value
+
+  has value : ro byte;
+
+The value.
+
 =head1 Class Methods
 
 =head2 new
@@ -29,10 +37,3 @@ L<Byte|SPVM::Byte> is automatically loaded just after the program starts.
 
 Create a new L<Byte|SPVM::Byte> object with a C<byte> value.
 
-=head1 Instance Methods
-
-=head2 value
-
-  method value : byte ()
-
-Get a C<byte> value.
